<?php
class BDConexion
{
 var $ConectId;
 function conectar()
 {
  $ConectId=mysql_connect("localhost","root","");
 }
 function BDConsulta($sql)
 {
  return mysql_db_query("BDPerenco",$sql);
 }
 function BDConsulta1($sql)
 {
  return mysql_db_query("BDPerenco",$sql);
 }
 function NextRow(&$ResultadoQuery)
 {
  return mysql_fetch_array($ResultadoQuery);
 }
 function NextRow1($ResultadoQuery)
 {
  return mysql_fetch_array($ResultadoQuery);
 }
 function NextRow2($ResultadoQuery)
 {
  return mysql_fetch_array($ResultadoQuery);
 }
 function Liberar(&$ResultadoQuery)
 {
  return mysql_free_result($ResultadoQuery);
 }
 function Liberar1(&$ResultadoQuery)
 {
  return mysql_free_result($ResultadoQuery);
 }
 function Liberar2(&$ResultadoQuery)
 {
  return mysql_free_result($ResultadoQuery);
 }
 function UltimoId()
 {
  return mysql_insert_id();
 }
 function totalrows($ResultadoQuery)
 {
  return mysql_num_rows($ResultadoQuery);
 }
}
?>