<?php
   class clsPer extends BDConexion
   {
     function clsPer()
     {
       $this->conectar();
     }
	 //*****************************************************************************************************
	 function getPais()
     {
       $ssql="select * ";
       $ssql.=" From pais ";       
       return $this->BDConsulta($ssql);
     }
	 function getEmp()
     {
       $ssql="select * ";
       $ssql.=" From empresas ";       
       return $this->BDConsulta($ssql);
     }
	 function getUsuarioDatos($idusuario)
     {
       $ssql="select * ";
       $ssql.=" From usuario where idusuario=$idusuario";       
       return $this->BDConsulta($ssql);
     }
	 function getOpcionMenu()
     {
       $ssql="select m.idmenu,g.nommenugrupo,m.nommenu ";
       $ssql.=" From menugrupo as g,menu as m where g.idmenugrupo=m.idmenugrupo and g.modulo='LAB' order by g.nommenugrupo asc";       
       return $this->BDConsulta($ssql);
     }
	 function getOpcionMenuSel($idusuario)
     {
       $ssql="select p.idpermiso,g.nommenugrupo,m.nommenu ";
       $ssql.=" From menugrupo as g,menu as m,permiso as p where g.idmenugrupo=m.idmenugrupo and p.idmenu=m.idmenu and g.modulo='LAB' and p.idusuario=$idusuario order by g.nommenugrupo asc";       
       return $this->BDConsulta($ssql);
     }
	 function getUsuarios($des,$regini,$regxpag)
     {
       $ssql="select concat(apellidos,' ',nombres) as nombre,login,idusuario,activo ";
       $ssql.=" From usuario where apellidos like '$des%' and modulo='LAB' order by apellidos asc limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function getUsu()
     {
       $ssql="select * ";
       $ssql.=" From usuario where activo='1' and modulo='LAB'";       
       return $this->BDConsulta($ssql);
     }
	 function getCboUsu($idusuario)
     {
       $lista="";
       $resultado=$this->getUsu();
       while($filas=$this->NextRow($resultado))
       {
         if($idusuario==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1].", ".$filas[2]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1].", ".$filas[2]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function getCboPais($cod_pais)
     {
       $lista="";
       $resultado=$this->getPais();
       while($filas=$this->NextRow($resultado))
       {
         if($cod_pais==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function getCboEmp($cod_emp)
     {
       $lista="";
       $resultado=$this->getEmp();
       while($filas=$this->NextRow($resultado))
       {
         if($cod_emp==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function ExistePersonal($dociden_per)
     {
       $ssql="select dociden_per from personal where dociden_per='$dociden_per' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $existe=$filas[0];
       else
           $existe=0;
       $this->Liberar($resultado);
       return $existe;
     }
	 function ExisteEmp($cod_emp)
     {
       $ssql="select cod_emp from empresas where cod_emp='$cod_emp' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $existe=$filas[0];
       else
           $existe=0;
       $this->Liberar($resultado);
       return $existe;
     }
	 function ExisteLoginClave($login,$clave)
     {
       $ssql="select clave from usuario where login='$login' or clave='$clave' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $existe=$filas[0];
       else
           $existe=0;
       $this->Liberar($resultado);
       return $existe;
     }
	 function ExisteClave($clave)
     {
       $ssql="select clave from usuario where clave='$clave' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $existe=$filas[0];
       else
           $existe=0;
       $this->Liberar($resultado);
       return $existe;
     }
	 function ExistePermiso($idusuario,$idmenu)
     {
       $ssql="select idusuario from permiso where idusuario=$idusuario and idmenu=$idmenu ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $existe=$filas[0];
       else
           $existe=0;
       $this->Liberar($resultado);
       return $existe;
     }
	 function getCboOpcionMenuSel($idusuario)
     {
       $lista="";
       $resultado=$this->getOpcionMenuSel($idusuario);
       while($filas=$this->NextRow($resultado))
       {
         if($idusuario==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."-".$filas[2]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."-".$filas[2]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function getCboOpcionMenu($idmenu)
     {
       $lista="";
       $resultado=$this->getOpcionMenu();
       while($filas=$this->NextRow($resultado))
       {
         if($idmenu==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."-".$filas[2]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."-".$filas[2]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function registrarPermiso($idusuario,$idmenu,$modulo)
     {
      $ssql="Insert Into permiso(idusuario,idmenu,modulo) values($idusuario,$idmenu,'$modulo')";
      $this->BDConsulta($ssql); 	        
     }
	 function DeletePermiso($idpermiso)
     {
      $ssql="delete from permiso where idpermiso=$idpermiso";
      $this->BDConsulta($ssql); 	        
     }
	 function DeleteUsuario($idusuario,$activo)
     {
      $ssql="update usuario set activo='$activo' where idusuario=$idusuario";
      $this->BDConsulta($ssql); 	        
     }
	 function UpdateUsuario($idusuario,$apellidos,$nombres,$login,$clave,$activo)
     {
      $ssql="update usuario set apellidos='$apellidos',nombres='$nombres',login='$login',clave='$clave',activo='$activo' where idusuario=$idusuario";
      $this->BDConsulta($ssql); 	        
     }
	 function registrarUsuario($apellidos,$nombres,$login,$clave,$activo,$modulo)
     {
      $ssql="Insert Into usuario(apellidos,nombres,login,clave,activo,modulo) values('$apellidos','$nombres','$login','$clave','$activo','$modulo')";
      $this->BDConsulta($ssql); 	        
     }
	 function registrarPersonal($cod_per,$appat_per,$apmat_per,$nom_per,$fnac_per,$cod_emp,$cod_pais,$fono_per,$cargo_per,$dociden_per,$peso_per)
     {
      $ssql="Insert Into personal(cod_per,appat_per,apmat_per,nom_per,fnac_per,cod_emp,cod_pais,fono_per,cargo_per,dociden_per,peso_per,activo_per) values('$cod_per','$appat_per','$apmat_per','$nom_per','$fnac_per','$cod_emp',$cod_pais,'$fono_per','$cargo_per','$dociden_per',$peso_per,'1')";
      $this->BDConsulta($ssql); 	        
     }
	 function registrarEmp($cod_emp,$razon_emp,$dir_emp,$ruc_emp,$contacto1_emp,$contacto2_emp,$cod_pais,$ciudad_emp)
     {
      $ssql="Insert Into empresas(cod_emp,razon_emp,dir_emp,ruc_emp,contacto1_emp,contacto2_emp,cod_pais,ciudad_emp) values('$cod_emp','$razon_emp','$dir_emp','$ruc_emp','$contacto1_emp','$contacto2_emp',$cod_pais,'$ciudad_emp')";
      $this->BDConsulta($ssql); 	        
     }
	 //*************************************************************************************************************
	 function UpdateHuesped($idhuesped,$huesped,$agencia,$direccion,$telefono,$profesion,$estadocivil,$idciudad,$docidentidad,$fecnac,$edad)
     {
      $ssql="update huesped set huesped='$huesped',agencia='$agencia',direccion='$direccion',telefono='$telefono',profesion='$profesion',estadocivil='$estadocivil',idciudad=$idciudad,docidentidad='$docidentidad',fecnac='$fecnac',edad=$edad where idhuesped=$idhuesped";
      $this->BDConsulta($ssql); 	        
     }	                           
	 function registrarAlojamiento($fechaingre,$fechasal,$horaingre,$procedencia,$destino,$idusuario,$idhabit,$idhuesped,$observacion,$estadoaloja)
     {
       $ssql="Insert Into alojamiento(fechaingre,fechasal,horaingre,procedencia,destino,idusuario,idhabit,idhuesped,observacion,estadoaloja) values('$fechaingre','$fechasal','$horaingre','$procedencia','$destino',$idusuario,$idhabit,$idhuesped,'$observacion','$estadoaloja')";
       $this->BDConsulta($ssql); 	   
	   $id=$this->UltimoId();
	   return $id; 
     }
	 
	 
     
     

   }

?>